pub enum WatcherV4Request {
Watch {
responder: WatcherV4WatchResponder,
},
}Expand description
An observer protocol for changes in system’s IPv4 routing state.
Variants
Watch
Hanging-Get style API for observing routing changes.
Clients must only have one pending Watch call at a time. Calling
Watch while a request is already pending will cause the protocol to
close.
The first N events will always be existing where N is the number of
IPv4 routes that already existed when the server-end of the protocol was
initialized. The following event will be idle signaling the end of the
existing events. At this point the client has watched all existing
state and will never again observe an existing event.
Events are returned in batches of up to MAX_EVENTS events. There is no
correlation between the batch size/boundary and it’s contents: it is
perfectly valid for the server to split the block of existing events,
across several batches. Clients should view this API as providing a
stream of events, where batches are used to reduce IPC load on the
system.
- response
eventsA vector of at mostMAX_EVENTSevents.
Fields
responder: WatcherV4WatchResponderImplementations
Sourceimpl WatcherV4Request
impl WatcherV4Request
pub fn into_watch(self) -> Option<WatcherV4WatchResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL