pub struct WatcherV6Proxy { /* private fields */ }Implementations
Sourceimpl WatcherV6Proxy
impl WatcherV6Proxy
Sourcepub fn take_event_stream(&self) -> WatcherV6EventStream
pub fn take_event_stream(&self) -> WatcherV6EventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn watch(&self) -> QueryResponseFut<Vec<EventV6>, FDomainResourceDialect>
pub fn watch(&self) -> QueryResponseFut<Vec<EventV6>, FDomainResourceDialect>
Hanging-Get style API for observing routing changes.
Clients must only have one pending Watch call at a time. Calling
Watch while a request is already pending will cause the protocol to
close.
The first N events will always be existing where N is the number of
IPv6 routes that already existed when the server-end of the protocol was
initialized. The following event will be idle signaling the end of the
existing events. At this point the client has watched all existing
state and will never again observe an existing event.
Events are returned in batches of up to MAX_EVENTS events. There is no
correlation between the batch size/boundary and it’s contents: it is
perfectly valid for the server to split the block of existing events,
across several batches. Clients should view this API as providing a
stream of events, where batches are used to reduce IPC load on the
system.
- response
eventsA vector of at mostMAX_EVENTSevents.